@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 """APIs for working with system components."""
+from .activity_logs import ActivityLogs
 from .central_core import CentralCore
 from .dashboard import Dashboard
 from .instances import Instances
 from .meta import Meta
+from .remote_support import RemoteSupport
 from .settings_global import SettingsGlobal
 from .settings_gui import SettingsGui
 from .settings_lifecycle import SettingsLifecycle
@@ -24,4 +26,6 @@ __all__ = (
     "System",
     "SystemRoles",
     "SystemUsers",
+    "RemoteSupport",
+    "ActivityLogs",
 )
