@@ -3,15 +3,9 @@
 import click
 
 from ..context import AliasedGroup
-from . import (
-    grp_central_core,
-    grp_discover,
-    grp_meta,
-    grp_nodes,
-    grp_roles,
-    grp_settings,
-    grp_users,
-)
+from . import (grp_activity_logs, grp_central_core, grp_discover, grp_meta,
+               grp_nodes, grp_remote_support, grp_roles, grp_settings,
+               grp_users)
 
 
 @click.group(cls=AliasedGroup)
@@ -28,3 +22,5 @@ system.add_command(grp_settings.settings_gui)
 system.add_command(grp_settings.settings_global)
 system.add_command(grp_users.users)
 system.add_command(grp_discover.discover)
+system.add_command(grp_remote_support.remote_support)
+system.add_command(grp_activity_logs.activity_logs)
